@@ -122,6 +122,7 @@ my %hierarchy = (
     'PathOutputFile' => 'OutputFile',
     'PatternFill' => 'FillFormat',
     'PdfExportOptions' => 'ExportOptions',
+    'PhantomElement' => 'MathElement',
     'PictureFill' => 'FillFormat',
     'PictureFrame' => 'GeometryShape',
     'Placeholder' => 'ResourceBase',
@@ -352,6 +353,7 @@ my %determiners = (
     'PatternFill' => { 'Type' => 'Pattern', },
     'PdfExportOptions' => { 'Format' => 'pdf', },
     'PdfImportOptions' => {  },
+    'PhantomElement' => { 'Type' => 'Phantom', },
     'PictureFill' => { 'Type' => 'Picture', },
     'PictureFrame' => { 'Type' => 'PictureFrame', },
     'Pipeline' => {  },
